@@ -1,4 +1,4 @@
-#' @title Bar plot of the relative gene expression from a one-factor experiment
+#' @title Bar plot of the relative gene expression (RE) from a one-factor experiment
 #' @description Bar plot of the relative expression of a gene along with the 95\% confidence interval and significance. There is another function, \code{qpcrTTESTplot}, that is used when the factor has two levels and represents Fold Change. \code{oneFACTORplot} is mainly useful for a one-factor experiment with more than two levels.
 #' @details The \code{oneFACTORplot} function generates the bar plot of the average fold change for target genes along with the significance and the 95\% confidence interval as error bars.
 #' @author Ghader Mirzaghaderi
@@ -19,7 +19,10 @@
 #' @param xlab  the title of the x axis.
 #' @param ylab  the title of the y axis.
 #' @param fontsize size of all fonts  of the plot.
+#' @param fontsizePvalue font size of the pvalue labels
 #' @param show.letters a logical variable. If TRUE, mean grouping letters are added to the bars.
+#' @param axis.text.x.angle angle of x axis text
+#' @param axis.text.x.hjust horizontal justification of x axis text
 #' @return Bar plot of the average fold change for target genes along with the significance and the 95\% confidence interval as error bars.
 #' @examples
 #'
@@ -53,7 +56,10 @@ oneFACTORplot <- function(x,
                           letter.position.adjust = 0.1,
                           ylab = "Relative Expression",
                           xlab = "Factor",
-                          fontsize = 12){
+                          fontsize = 12,
+                          fontsizePvalue = 7,
+                          axis.text.x.angle = 0,
+                          axis.text.x.hjust = 0.5){
 
   RE <- x$RE
   std <- x$std
@@ -67,7 +73,7 @@ oneFACTORplot <- function(x,
     ylab(ylab) +
     xlab(xlab) +
     theme_bw() +
-    theme(axis.text.x = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
+    theme(axis.text.x = element_text(size = fontsize, color = "black", angle = axis.text.x.angle, hjust = axis.text.x.hjust),
           axis.text.y = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
           axis.title  = element_text(size = fontsize),
           legend.text = element_text(size = fontsize)) +
@@ -77,7 +83,7 @@ oneFACTORplot <- function(x,
   if (show.letters) {
     q1f1 <-q1f1 +
       geom_text(data = x, aes(label = letters, x = rownames(x), y = RE + std + letter.position.adjust),
-                vjust = -0.5, size = 4)
+                vjust = -0.5, size = fontsizePvalue)
   }
 
 
@@ -90,7 +96,7 @@ oneFACTORplot <- function(x,
     ylab(ylab) +
     xlab(xlab) +
     theme_bw() +
-    theme(axis.text.x = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
+    theme(axis.text.x = element_text(size = fontsize, color = "black", angle = axis.text.x.angle, hjust = axis.text.x.hjust),
           axis.text.y = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
           axis.title  = element_text(size = fontsize),
           legend.text = element_text(size = fontsize)) +
@@ -100,7 +106,7 @@ oneFACTORplot <- function(x,
   if (show.letters) {
     q1f2 <- q1f2 +
       geom_text(data = x, aes(label = letters, x = rownames(x), y = RE + LCL + letter.position.adjust),
-                vjust = -0.5, size = 4)
+                vjust = -0.5, size = fontsizePvalue)
   }
 
 
