@@ -21,8 +21,11 @@
 #' @param letter.position.adjust adjust the distance between the grouping letters to the error bars
 #' @param legend.title legend title
 #' @param fontsize all fonts size of the plot
+#' @param fontsizePvalue font size of the pvalue labels
 #' @param legend.position a two digit vector specifying the legend position.
 #' @param show.letters a logical variable. If TRUE, mean grouping letters are added to the bars. 
+#' @param axis.text.x.angle angle of x axis text
+#' @param axis.text.x.hjust horizontal justification of x axis text
 #' @return Bar plot of the average fold change for target genes along with the significance and the 95\% confidence interval as error bars.
 #' @examples
 #' 
@@ -100,7 +103,10 @@ threeFACTORplot <- function(x,
                          legend.title = "Legend Title",
                          legend.position = c(0.4, 0.8),
                          fontsize = 12,
-                         show.letters = TRUE){
+                         fontsizePvalue = 7,
+                         show.letters = TRUE,
+                         axis.text.x.angle = 0,
+                         axis.text.x.hjust = 0.5){
   
   x <- x[, c(arrangement, 4:ncol(x))]
   RE <- x$RE
@@ -123,7 +129,7 @@ threeFACTORplot <- function(x,
                                       y.axis.adjust, by = y.axis.by),
                        limits = c(0, max(x$RE) + max(x$std) + y.axis.adjust),
                        expand = c(0, 0)) +
-    theme(axis.text.x = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
+    theme(axis.text.x = element_text(size = fontsize, color = "black", angle = axis.text.x.angle, hjust = axis.text.x.hjust),
           axis.text.y = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
           axis.title  = element_text(size = fontsize)) +
     theme(legend.text = element_text(colour = "black", size = fontsize),
@@ -135,7 +141,7 @@ threeFACTORplot <- function(x,
   if (show.letters) {
     pp1 <- pp1 + 
       geom_text(data = x, aes(label=letters, y = RE + std + letter.position.adjust), color = "black",
-                show.legend = FALSE, position = position_dodge(bar.width))
+                show.legend = FALSE, position = position_dodge(bar.width), size = fontsizePvalue)
   }
   
   
@@ -154,7 +160,7 @@ threeFACTORplot <- function(x,
                                       y.axis.adjust, by = y.axis.by),
                        limits = c(0, max(x$RE) + max(x$LCL) + y.axis.adjust),
                        expand = c(0, 0)) +
-    theme(axis.text.x = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
+    theme(axis.text.x = element_text(size = fontsize, color = "black", angle = axis.text.x.angle, hjust = axis.text.x.hjust),
           axis.text.y = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
           axis.title  = element_text(size = fontsize)) +
     theme(legend.text = element_text(colour = "black", size = fontsize),
@@ -166,7 +172,7 @@ threeFACTORplot <- function(x,
   if (show.letters) {
     pp2 <- pp2 +
       geom_text(data = x, aes(label=letters, y = RE + LCL + letter.position.adjust), color = "black",
-                show.legend = FALSE, position = position_dodge(bar.width))
+                show.legend = FALSE, position = position_dodge(bar.width), size = fontsizePvalue)
   }
   
   
